@@ -72,6 +72,7 @@
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QToolButton>
+#include <QHeaderView>
 
 using namespace KIdentityManagement;
 using namespace KCalendarCore;
@@ -146,6 +147,8 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
         connect(
             calendar.data(), &Akonadi::ETMCalendar::calendarChanged, this,
             &AlarmDialog::slotCalendarChanged);
+        Akonadi::IncidenceChanger *changer = calendar->incidenceChanger();
+        changer->setShowDialogsOnError(false);
     }
 
     KIconLoader::global()->addAppDir(QStringLiteral("korgac"));
@@ -166,7 +169,7 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     defSuspendVal = generalConfig.readEntry("DefaultSuspendValue", defSuspendVal);
     int suspendVal = generalConfig.readEntry("SuspendValue", defSuspendVal);
 
-    defSuspendUnit = generalConfig.readEntry("SuspendUnit", defSuspendUnit);
+    defSuspendUnit = generalConfig.readEntry("DefaultSuspendUnit", defSuspendUnit);
     SuspendUnit suspendUnit = static_cast<SuspendUnit>(generalConfig.readEntry("SuspendUnit",
                                                                                defSuspendUnit));
 
@@ -179,10 +182,13 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
     mOkButton = new QToolButton;
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     mUser1Button = new QPushButton;
+    mUser1Button->setDefault(false);
     buttonBox->addButton(mUser1Button, QDialogButtonBox::ActionRole);
     mUser2Button = new QPushButton;
+    mUser2Button->setDefault(false);
     buttonBox->addButton(mUser2Button, QDialogButtonBox::ActionRole);
     mUser3Button = new QPushButton;
+    mUser3Button->setDefault(false);
     buttonBox->addButton(mUser3Button, QDialogButtonBox::ActionRole);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &AlarmDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &AlarmDialog::reject);
@@ -240,12 +246,20 @@ AlarmDialog::AlarmDialog(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *par
            << i18nc("@title:column happens at date/time", "Date Time")
            << i18nc("@title:column trigger date/time", "Trigger Time"));
     mIncidenceTree->setHeaderLabels(headerLabels);
+
+    QHeaderView *header = mIncidenceTree->header();
+    header->setSectionResizeMode(0, QHeaderView::Stretch);
     mIncidenceTree->headerItem()->setToolTip(
         0,
         i18nc("@info:tooltip", "The event or to-do title"));
+
+    header->setSectionResizeMode(1, QHeaderView::ResizeToContents);
     mIncidenceTree->headerItem()->setToolTip(
         1,
         i18nc("@info:tooltip", "The reminder is set for this date/time"));
+
+    header->setSectionResizeMode(2, QHeaderView::ResizeToContents);
+    header->setStretchLastSection(false);
     mIncidenceTree->headerItem()->setToolTip(
         2,
         i18nc("@info:tooltip", "The date/time the reminder was triggered"));
@@ -373,19 +387,13 @@ ReminderTreeItem *AlarmDialog::searchByItem(const Akonadi::Item &incidence)
 
 static QString cleanSummary(const QString &summary)
 {
-    static QString etc = i18nc("@label an ellipsis", "...");
-    int maxLen = 30;
     QString retStr = summary;
-    retStr.replace(QLatin1Char('\n'), QLatin1Char(' '));
-    if (retStr.length() > maxLen) {
-        maxLen -= etc.length();
-        retStr.truncate(maxLen);
-        retStr += etc;
-    }
-    return retStr;
+    return retStr.replace(QLatin1Char('\n'), QLatin1Char(' '));
 }
 
-void AlarmDialog::addIncidence(const Akonadi::Item &incidenceitem, const QDateTime &reminderAt, const QString &displayText)
+void AlarmDialog::addIncidence(const Akonadi::Item &incidenceitem,
+                               const QDateTime &reminderAt,
+                               const QString &displayText)
 {
     Incidence::Ptr incidence = CalendarSupport::incidence(incidenceitem);
     ReminderTreeItem *item = searchByItem(incidenceitem);
@@ -529,12 +537,19 @@ void AlarmDialog::edit()
             KMessageBox::sorry(
                 this,
                 i18nc("@info",
-                      "\"%1\" is a read-only item so modifications are not possible.",
+                      "\"%1\" is a read-only incidence so modifications are not possible.",
                       cleanSummary(incidence->summary())));
             return;
         }
 
-        openIncidenceEditorNG(selection.first()->mIncidence);
+        if (!openIncidenceEditorNG(selection.first()->mIncidence)) {
+            KMessageBox::error(
+                this,
+                i18nc("@info",
+                      "An internal error occurred attempting to modify \"%1\". Unsupported type.",
+                      cleanSummary(incidence->summary())));
+            qCWarning(KOALARMCLIENT_LOG) << "Attempting to edit an unsupported incidence type.";
+        }
     }
 }
 
@@ -773,8 +788,20 @@ void AlarmDialog::eventNotification()
                 }
                 //TODO: support attachments
                 KOrg::MailClient mailer;
-                mailer.send(id, from, to, QString(), subject, body, true, false, QString(),
-                            MailTransport::TransportManager::self()->defaultTransportName());
+                const bool sendStatus =
+                    mailer.send(id, from, to, QString(), subject, body, true, false, QString(),
+                                MailTransport::TransportManager::self()->defaultTransportName());
+                if (!sendStatus) {
+                    KNotification::event(QStringLiteral("mailremindersent"),
+                        QString(),
+                        i18nc("@info email subject, error message",
+                              "<warning>Failed to send the Email reminder for %1. %2</warning>",
+                              subject, mailer.errorMsg()),
+                        QStringLiteral("korgac"),
+                        nullptr,
+                        KNotification::CloseOnTimeout,
+                        QStringLiteral("korgac"));
+                }
             }
         }
     }
@@ -830,10 +857,9 @@ void AlarmDialog::wakeUp()
     Q_EMIT reminderCount(activeCount());
 }
 
-void AlarmDialog::slotDBusNotificationsPropertiesChanged(
-        const QString& interface,
-        const QVariantMap& changedProperties,
-        const QStringList& invalidatedProperties)
+void AlarmDialog::slotDBusNotificationsPropertiesChanged(const QString &interface,
+                                                         const QVariantMap &changedProperties,
+                                                         const QStringList &invalidatedProperties)
 {
     Q_UNUSED(interface); // always "org.freedesktop.Notifications"
     Q_UNUSED(invalidatedProperties);
@@ -847,7 +873,6 @@ void AlarmDialog::slotDBusNotificationsPropertiesChanged(
     }
 }
 
-
 void AlarmDialog::slotSave()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
@@ -937,6 +962,10 @@ void AlarmDialog::updateButtons()
     } else {
         mUser1Button->setEnabled(false);
     }
+    if (enabled) {
+       mIncidenceTree->setFocus();
+       mIncidenceTree->setCurrentItem(selection.first());
+    }
 }
 
 void AlarmDialog::toggleDetails(QTreeWidgetItem *item)
@@ -1004,7 +1033,9 @@ void AlarmDialog::accept()
 }
 
 /** static */
-QDateTime AlarmDialog::triggerDateForIncidence(const Incidence::Ptr &incidence, const QDateTime &reminderAt, QString &displayStr)
+QDateTime AlarmDialog::triggerDateForIncidence(const Incidence::Ptr &incidence,
+                                               const QDateTime &reminderAt,
+                                               QString &displayStr)
 {
     QDateTime result;
 
@@ -1129,12 +1160,16 @@ bool AlarmDialog::openIncidenceEditorThroughKOrganizer(const Incidence::Ptr &inc
 bool AlarmDialog::openIncidenceEditorNG(const Akonadi::Item &item)
 {
     Incidence::Ptr incidence = CalendarSupport::incidence(item);
-    IncidenceEditorNG::IncidenceDialog *dialog
-        = IncidenceEditorNG::IncidenceDialogFactory::create(
-              false, /*doesn't need initial saving*/
-              incidence->type(), nullptr, this);
-    dialog->load(item);
-    return true;
+    IncidenceEditorNG::IncidenceDialog *dialog =
+        IncidenceEditorNG::IncidenceDialogFactory::create(
+            false, /*doesn't need initial saving*/
+            incidence->type(), nullptr, this);
+    if (!dialog) {
+        return false;
+    } else {
+        dialog->load(item);
+        return true;
+    }
 }
 
 void AlarmDialog::removeFromConfig(const QList<Akonadi::Item::Id> &ids)
