@@ -87,11 +87,17 @@ NoteEditDialog::NoteEditDialog(QWidget *parent)
                                                       "Calendar where the new note will be stored."));
 #endif
     mCollectionCombobox->setToolTip(i18n("Calendar where the new note will be stored."));
-
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(mCollectionCombobox,
             QOverload<int>::of(
                 &Akonadi::CollectionComboBox::currentIndexChanged), this,
             &NoteEditDialog::slotCollectionChanged);
+#else
+    connect(mCollectionCombobox,
+            QOverload<int, const QString &>::of(
+                &Akonadi::CollectionComboBox::currentIndexChanged), this,
+            &NoteEditDialog::slotCollectionChanged);
+#endif
     connect(mCollectionCombobox, QOverload<int>::of(
                 &Akonadi::CollectionComboBox::activated), this,
             &NoteEditDialog::slotCollectionChanged);
