@@ -26,7 +26,6 @@
 #include "apptsummarywidget.h"
 #include "korganizerplugin.h"
 #include "summaryeventinfo.h"
-
 #include "korganizerinterface.h"
 
 #include <CalendarSupport/Utils>
@@ -209,11 +208,12 @@ void ApptSummaryWidget::updateView()
         urlLabel->setWordWrap(true);
         mLayout->addWidget(urlLabel, counter, 3);
         mLabels.append(urlLabel);
-
-        connect(urlLabel, QOverload<const QString &>::of(
-                    &KUrlLabel::leftClickedUrl), this, &ApptSummaryWidget::viewEvent);
-        connect(urlLabel, QOverload<const QString &>::of(
-                    &KUrlLabel::rightClickedUrl), this, &ApptSummaryWidget::popupMenu);
+        connect(urlLabel, &KUrlLabel::leftClickedUrl, this, [this, urlLabel] {
+            viewEvent(urlLabel->url());
+        });
+        connect(urlLabel, &KUrlLabel::rightClickedUrl, this, [this, urlLabel] {
+            popupMenu(urlLabel->url());
+        });
         if (!event->summaryTooltip.isEmpty()) {
             urlLabel->setToolTip(event->summaryTooltip);
         }
