@@ -31,7 +31,7 @@
 
 #include <KContacts/VCardDrag>
 
-#include <KCalCore/MemoryCalendar>
+#include <KCalendarCore/MemoryCalendar>
 
 #include <KCalUtils/ICalDrag>
 
@@ -41,7 +41,6 @@
 #include <KActionCollection>
 #include "korganizerplugin_debug.h"
 #include <QIcon>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <QTemporaryFile>
@@ -55,7 +54,6 @@ TodoPlugin::TodoPlugin(KontactInterface::Core *core, const QVariantList &)
     , mIface(nullptr)
 {
     setComponentName(QStringLiteral("korganizer"), i18n("KOrganizer"));
-    KIconLoader::global()->addAppDir(QStringLiteral("korganizer"));
 
     QAction *action
         = new QAction(QIcon::fromTheme(QStringLiteral("task-new")),
@@ -139,17 +137,6 @@ void TodoPlugin::slotNewTodo()
     interface()->openTodoEditor(QString());
 }
 
-bool TodoPlugin::createDBUSInterface(const QString &serviceType)
-{
-    if (serviceType == QLatin1String("DBUS/Organizer")
-        || serviceType == QLatin1String("DBUS/Calendar")) {
-        if (part()) {
-            return true;
-        }
-    }
-    return false;
-}
-
 bool TodoPlugin::canDecodeMimeData(const QMimeData *mimeData) const
 {
     return
@@ -192,15 +179,15 @@ void TodoPlugin::processDropEvent(QDropEvent *event)
     }
 
     if (KCalUtils::ICalDrag::canDecode(event->mimeData())) {
-        KCalCore::MemoryCalendar::Ptr cal(new KCalCore::MemoryCalendar(QTimeZone::systemTimeZone()));
+        KCalendarCore::MemoryCalendar::Ptr cal(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
         if (KCalUtils::ICalDrag::fromMimeData(event->mimeData(), cal)) {
-            KCalCore::Incidence::List incidences = cal->incidences();
+            KCalendarCore::Incidence::List incidences = cal->incidences();
             Q_ASSERT(incidences.count());
             if (!incidences.isEmpty()) {
                 event->accept();
-                KCalCore::Incidence::Ptr i = incidences.first();
+                KCalendarCore::Incidence::Ptr i = incidences.first();
                 QString summary;
-                if (i->type() == KCalCore::Incidence::TypeJournal) {
+                if (i->type() == KCalendarCore::Incidence::TypeJournal) {
                     summary = i18nc("@item", "Note: %1", i->summary());
                 } else {
                     summary = i->summary();
